"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require('fs');
function wrap(formatter, dst) {
    return (results) => {
        const output = formatter(results);
        if (dst) {
            fs.writeFileSync(dst, output, 'utf-8');
        }
        else {
            process.stdout.write(output);
        }
    };
}
function getFormatter(formatters) {
    const fn = formatters
        .split(',')
        .map(cur => {
        const [name, dst] = cur.split('=', 2);
        const moduleName = name.replace(/[^a-z]+/g, '');
        const formatter = require(`../formatters/${moduleName}`);
        return wrap(formatter, dst);
    });
    return (report) => {
        fn.forEach((formatter) => formatter(report.results));
    };
}
exports.getFormatter = getFormatter;
