"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class EventHandler {
    constructor() {
        this.listeners = {};
    }
    on(event, callback) {
        const names = event.split(',').map((x) => x.trim());
        for (const name of names) {
            this.listeners[name] = this.listeners[name] || [];
            this.listeners[name].push(callback);
        }
        return () => {
            for (const name of names) {
                this.listeners[name] = this.listeners[name].filter((fn) => {
                    return fn !== callback;
                });
            }
        };
    }
    once(event, callback) {
        const deregister = this.on(event, (event, data) => {
            callback(event, data);
            deregister();
        });
        return deregister;
    }
    trigger(event, data) {
        const callbacks = [].concat(this.listeners[event] || [], this.listeners['*'] || []);
        callbacks.forEach(listener => {
            listener.call(null, event, data);
        });
    }
}
exports.EventHandler = EventHandler;
exports.default = EventHandler;
