"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rule_1 = require("../rule");
class HeadingLevel extends rule_1.Rule {
    setup() {
        let current = 0;
        this.on('tag:open', (event) => {
            if (!this.isHeading(event.target))
                return;
            const level = this.extractLevel(event.target);
            if (!level)
                return;
            if (level <= current) {
                current = level;
                return;
            }
            const expected = current + 1;
            if (level !== expected) {
                if (current > 0) {
                    this.report(event.target, `Heading level can only increase by one, expected h${expected}`);
                }
                else {
                    this.report(event.target, `Initial heading level must be h${expected}`);
                }
            }
            current = level;
        });
    }
    isHeading(node) {
        return node.meta && !!node.meta.heading;
    }
    extractLevel(node) {
        const match = node.tagName.match(/^[hH](\d)$/);
        return match ? parseInt(match[1], 10) : null;
    }
}
module.exports = HeadingLevel;
